import java.io.*;
import java.util.*;

public class Erdos {
    public static void main(String[] args) {
	try {
	    BufferedReader reader =
		new BufferedReader(new FileReader("erdos.in"));
	    BufferedWriter writer =
		new BufferedWriter(new FileWriter("erdos.out"));

	    int dbid = 0;
	    while (true) {
		dbid++;
		StringTokenizer tokenizer =
		    new StringTokenizer(reader.readLine());
		int paperCount = 
		    Integer.parseInt(tokenizer.nextToken());
		int authorCount =
		    Integer.parseInt(tokenizer.nextToken());
		if (paperCount == 0)
		    break;

		HashMap authors = new HashMap(625, 1.0f);
		Author erdos = new Author(" Erdos, P.");
		authors.put(" Erdos, P.", erdos);

		int i, j;
		for (i = 0; i < paperCount; i++) {
		    tokenizer = new StringTokenizer(
				    " " + reader.readLine(),",:");
		    int n = (tokenizer.countTokens() - 1) / 2;
		    Paper p = new Paper();
		    for (j = 0; j < n; j++) {
			String name =
			    tokenizer.nextToken() + "," +
			    tokenizer.nextToken();
			Author a;
			if (authors.containsKey(name)) {
			    a = (Author)authors.get(name);
			} else {
			    a = new Author(name);
			    authors.put(name, a);
			}
			p.authors.add(a);
		    }
		    p.name = tokenizer.nextToken();
		    if (tokenizer.hasMoreTokens()) {
			System.err.println("Invalid data");
		    }
		    Iterator it = p.authors.iterator();
		    while (it.hasNext()) {
			((Author)it.next()).papers.add(p);
		    }
		}
		/*
		Iterator it = authors.values().iterator();
		while (it.hasNext()) {
		    ((Author)it.next()).dump();
		}
		*/
		erdos.setNumber(0);
		writer.write("Database #" + dbid);
		writer.newLine();
		for (i = 0; i < authorCount; i++) {
		    String name = reader.readLine();
		    Author a = (Author)authors.get(" " + name);
		    if (a == null || a.number == Author.INFTY)
			writer.write(name + ": infinity");
		    else
			writer.write(name + ": " + a.number);
		    writer.newLine();
		}
		writer.newLine();
		writer.flush();
	    }
	} catch (IOException e) {
	    System.err.println("I/O Error");
	}
    }
}
class Author {
    String name;
    static final int INFTY = 65536;
    int number = INFTY;
    ArrayList papers = new ArrayList();
    Author (String name) {
	this.name = name;
    }
    void setNumber(int number) {
	if (number < this.number) {
	    this.number = number;
	    Iterator it_p = papers.iterator();
	    while (it_p.hasNext()) {
		Paper p = (Paper)it_p.next();
		Iterator it_a = p.authors.iterator();
		while (it_a.hasNext()) {
		    ((Author)it_a.next()).setNumber(number + 1);
		}
	    }
	}
    }
    void dump() {
	Iterator it = papers.iterator();
	System.out.print(name + ":");
	while (it.hasNext())
	    System.out.print(((Paper)it.next()).name + " ");
	System.out.println("");
    }
}
class Paper {
    ArrayList authors = new ArrayList();
    String name;
}
