import java.io.*;
import java.util.*;
import java.text.*;

public class Railroad {
    public static void main(String[] args) {
	try {
	    BufferedReader reader =
		new BufferedReader(new FileReader("railroad.in"));
	    BufferedWriter writer =
		new BufferedWriter(new FileWriter("railroad.out"));
	    DecimalFormat df = new DecimalFormat("0000");

	    int scenario_id = 0;
	    while (true) {
		scenario_id++;
		int cityCount = Integer.parseInt(reader.readLine());
		if (cityCount == 0)
		    break;

		int i, j;

		HashMap cities = new HashMap(cityCount, 1.0f);
		for (i = 0; i < cityCount; i++) {
		    String name = reader.readLine();
		    cities.put(name, new City(name));
		}

		int trainCount = Integer.parseInt(reader.readLine());
		for (i = 0; i < trainCount; i++) {
		    int stopCityCount = 
			Integer.parseInt(reader.readLine());
		    //first city and time
		    String buf = reader.readLine();
		    int departTime = 
			Integer.parseInt(buf.substring(0, 4));
		    City departCity = (City)cities.get(buf.substring(5));
		    for (j = 1; j < stopCityCount; j++) {
			buf = reader.readLine();
			int arriveTime = 
			    Integer.parseInt(buf.substring(0, 4));
			City arriveCity = (City)cities.get(buf.substring(5));
			Train t = new Train(departTime, departCity,
					    arriveTime, arriveCity);
			departCity.departTrains.add(t);
			arriveCity.arriveTrains.add(t);
			departTime = arriveTime;
			departCity = arriveCity;
		    }
		}
		int startTime = Integer.parseInt(reader.readLine());
		City departCity = (City)cities.get(reader.readLine());
		City arriveCity = (City)cities.get(reader.readLine());

		writer.write("Scenario #" + scenario_id);
		writer.newLine();
		//search
		departCity.searchForward(startTime);
		if (arriveCity.earliestArrive == 10000) {
		    writer.write("No connection");
		    writer.newLine();
		} else {
		    arriveCity.searchBackward(arriveCity.earliestArrive);
		    writer.write("Departure " + 
				 df.format(departCity.latestDepart) +
				 " " + departCity.name);
		    writer.newLine();
		    writer.write("Arrival   " + 
				 df.format(arriveCity.earliestArrive) +
				 " " + arriveCity.name);
		    writer.newLine();
		}
		writer.newLine();
		writer.flush();
	    }
	} catch (IOException e) {
	    System.err.println("I/O Error");
	}
    }
}
class Train {
    int departTime;
    int arriveTime;
    City departCity;
    City arriveCity;
    Train(int departTime, City departCity, int arriveTime, City arriveCity) {
	this.departTime = departTime;
	this.departCity = departCity;
	this.arriveTime = arriveTime;
	this.arriveCity = arriveCity;
    }
}
class City {
    String name;
    ArrayList departTrains = new ArrayList();
    ArrayList arriveTrains = new ArrayList();
    int earliestArrive = 10000;
    int latestDepart = -1;
    City(String name) {
	this.name = name;
    }
    void searchForward(int time) {
	if (earliestArrive > time) {
	    earliestArrive = time;
	    Iterator it = departTrains.iterator();
	    while (it.hasNext()) {
		Train t = (Train)it.next();
		if (t.departCity != this) {
		    System.err.println("Data Structure Broken");
		}
		if (t.departTime >= time) {
		    t.arriveCity.searchForward(t.arriveTime);
		}
	    }
	}
    }
    void searchBackward(int time) {
	if (latestDepart < time) {
	    latestDepart = time;
	    Iterator it = arriveTrains.iterator();
	    while (it.hasNext()) {
		Train t = (Train)it.next();
		if (t.arriveCity != this) {
		    System.err.println("Data Structure Broken");
		}
		if (t.arriveTime <= time) {
		    t.departCity.searchBackward(t.departTime);
		}
	    }
	}
    }
	    
}
